"""
crawl4ai-client — Lightweight async client for Crawl4AI Docker server.

No browser or heavy dependencies required. Just httpx + pydantic.

Usage:
    from crawl4ai_client import Crawl4aiDockerClient

    async with Crawl4aiDockerClient(base_url="http://localhost:11235") as client:
        result = await client.crawl(["https://example.com"])
        print(result.markdown)
"""

from .client import (
    Crawl4aiDockerClient,
    Crawl4aiClientError,
    ConnectionError,
    RequestError,
)
from .models import CrawlResult, MarkdownResult
from .config import BrowserConfig, CrawlerRunConfig, CacheMode

__version__ = "0.1.0"

__all__ = [
    "Crawl4aiDockerClient",
    "Crawl4aiClientError",
    "ConnectionError",
    "RequestError",
    "CrawlResult",
    "MarkdownResult",
    "BrowserConfig",
    "CrawlerRunConfig",
    "CacheMode",
]
